diff --git a/src/lxc/conf.c b/src/lxc/conf.c
index b437654..71e7d26 100644
--- a/src/lxc/conf.c
+++ b/src/lxc/conf.c
@@ -2000,6 +2045,8 @@ void lxc_delete_network(struct lxc_list *network)
 			continue;
 
 		if (netdev->type == LXC_NET_PHYS) {
+			DEBUG("rename to the initial name the " \
+			     "netdev '%s' ifindex %d", netdev->link,netdev->ifindex);
 			if (lxc_netdev_rename_by_index(netdev->ifindex, netdev->link))
 				WARN("failed to rename to the initial name the " \
 				     "netdev '%s'", netdev->link);
@@ -2010,8 +2057,8 @@ void lxc_delete_network(struct lxc_list *network)
 		 * namespace is destroyed but in case we did not moved the
 		 * interface to the network namespace, we have to destroy it
 		 */
-		if (lxc_netdev_delete_by_index(netdev->ifindex))
-			WARN("failed to remove interface '%s'", netdev->name);
+		DEBUG("remove interface '%s'", netdev->name);
+		lxc_netdev_delete_by_index(netdev->ifindex);
 	}
 }
 
diff --git a/src/lxc/start.c b/src/lxc/start.c
index 19815fc..60548b0 100644
--- a/src/lxc/start.c
+++ b/src/lxc/start.c
@@ -547,9 +547,10 @@ out_warn_father:
 	return -1;
 }
 
+static int clone_flags;
+
 int lxc_spawn(struct lxc_handler *handler)
 {
-	int clone_flags;
 	int failed_before_rename = 0;
 	const char *name = handler->name;
 	int pinfd;
@@ -710,6 +711,9 @@ int __lxc_start(const char *name, struct lxc_conf *conf,
 
 	err =  lxc_error_set_and_log(handler->pid, status);
 out_fini:
+	if (clone_flags & CLONE_NEWNET)
+		lxc_delete_network(&handler->conf->network);
+
 	lxc_cgroup_destroy(name);
 	lxc_fini(name, handler);
 	return err;
